# cipred

Non-parametric error prediction with random forest model in python.

[![DOI](https://zenodo.org/badge/605932757.svg)](https://zenodo.org/badge/latestdoi/605932757)


## install from source
```bash
cd /tmp
git clone https://github.com/j-m-l-e-u/cipred_pkg.git
cd cipred_pkg
pip3 install -e .
```

Package 'cipred' has been tested on python 3.8 and 3.9

## References

- [A Unified Framework for Random Forest Prediction Error Estimation](https://www.jmlr.org/papers/volume22/18-558/18-558.pdf), and

- [Error Prediction of Air Quality at Monitoring Stations Using Random Forest in a Total Error Framework](https://www.mdpi.com/1424-8220/21/6/2160/htm).

## For R users

Please use the R-package [forestError](https://github.com/benjilu/forestError).
